@@ -3,7 +3,7 @@ package Filename::Image;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-20'; # DATE
 our $DIST = 'Filename-Image'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,7 +12,7 @@ use warnings;
 use Exporter qw(import);
 our @EXPORT_OK = qw(check_image_filename);
 
-our $STR_RE = "djvu|jpeg|jpg2|svgz|tiff|wbmp|art|bmp|cdr|cdt|cpt|cr2|crw|djv|erf|gif|ico|ief|jng|jp2|jpe|jpf|jpg|jpm|jpx|nef|orf|pat|pbm|pcx|pgm|png|pnm|ppm|psd|ras|rgb|svg|tif|xbm|xpm|xwd"; # STR_RE
+our $STR_RE = "djvu|jpeg|jpg2|svgz|tiff|wbmp|webp|art|bmp|cdr|cdt|cpt|cr2|crw|djv|erf|gif|ico|ief|jng|jp2|jpe|jpf|jpg|jpm|jpx|nef|orf|pat|pbm|pcx|pgm|png|pnm|ppm|psd|ras|rgb|svg|tif|xbm|xcf|xpm|xwd"; # STR_RE
 
 our $RE = qr(\.(?:$STR_RE)\z)i;
 
@@ -88,7 +88,7 @@ Filename::Image - Check whether filename indicates being an image
 
 =head1 VERSION
 
-This document describes version 0.004 of Filename::Image (from Perl distribution Filename-Image), released on 2020-10-20.
+This document describes version 0.005 of Filename::Image (from Perl distribution Filename-Image), released on 2020-10-20.
 
 =head1 SYNOPSIS
 
